@@ -1,4 +1,4 @@
-//@line 37 "/export/home/mozilla/uild/firefox1.5.0.2/mozilla/browser/components/preferences/permissions.js"
+//@line 39 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/browser/components/preferences/permissions.js"
 
 const nsIPermissionManager = Components.interfaces.nsIPermissionManager;
 const nsICookiePermission = Components.interfaces.nsICookiePermission;
@@ -45,7 +45,10 @@ var gPermissionManager = {
     cycleHeader: function(column) {},
     getRowProperties: function(row,prop){},
     getColumnProperties: function(column,prop){},
-    getCellProperties: function(row,column,prop){}
+    getCellProperties: function(row,column,prop){
+      if (column.element.getAttribute("id") == "siteCol")
+        prop.AppendElement(this._ltrAtom);
+    }
   },
   
   _getCapabilityString: function (aCapability)
@@ -89,9 +92,10 @@ var gPermissionManager = {
     var exists = false;
     for (var i = 0; i < this._permissions.length; ++i) {
       if (this._permissions[i].rawHost == host) {
-        exists = true;
-        this._permissions[i].capability = capabilityString;
-        this._permissions[i].perm = aCapability;
+        // Avoid calling the permission manager if the capability settings are
+        // the same. Otherwise allow the call to the permissions manager to
+        // update the listbox for us.
+        exists = this._permissions[i].perm == aCapability;
         break;
       }
     }
@@ -120,8 +124,8 @@ var gPermissionManager = {
   
   onHostKeyPress: function (aEvent)
   {
-    if (aEvent.keyCode == 13)
-      gPermissionManager.addPermission(nsIPermissionManager.ALLOW_ACTION);
+    if (aEvent.keyCode == KeyEvent.DOM_VK_RETURN)
+      document.getElementById("btnAllow").click();
   },
   
   onLoad: function ()
@@ -133,7 +137,13 @@ var gPermissionManager = {
   
   init: function (aParams)
   {
+    if (this._type) {
+      // reusing an open dialog, clear the old observer
+      this.uninit();
+    }
+
     this._type = aParams.permissionType;
+    this._manageCapability = aParams.manageCapability;
     
     var permissionsText = document.getElementById("permissionsText");
     while (permissionsText.hasChildNodes())
@@ -145,12 +155,18 @@ var gPermissionManager = {
     document.getElementById("btnBlock").hidden    = !aParams.blockVisible;
     document.getElementById("btnSession").hidden  = !aParams.sessionVisible;
     document.getElementById("btnAllow").hidden    = !aParams.allowVisible;
-    
+
+    var urlFieldVisible = (aParams.blockVisible || aParams.sessionVisible || aParams.allowVisible);
+
     var urlField = document.getElementById("url");
     urlField.value = aParams.prefilledHost;
-    
+    urlField.hidden = !urlFieldVisible;
+
     this.onHostInput(urlField);
-    
+
+    var urlLabel = document.getElementById("urlLabel");
+    urlLabel.hidden = !urlFieldVisible;
+
     var os = Components.classes["@mozilla.org/observer-service;1"]
                        .getService(Components.interfaces.nsIObserverService);
     os.addObserver(this, "perm-changed", false);
@@ -164,6 +180,10 @@ var gPermissionManager = {
     this._loadPermissions();
     
     urlField.focus();
+
+    this._ltrAtom = Components.classes["@mozilla.org/atom-service;1"]
+                              .getService(Components.interfaces.nsIAtomService)
+                              .getAtom("ltr");
   },
   
   uninit: function ()
@@ -291,7 +311,10 @@ var gPermissionManager = {
   
   _addPermissionToList: function (aPermission)
   {
-    if (aPermission.type == this._type) {
+    if (aPermission.type == this._type &&
+        (!this._manageCapability ||
+         (aPermission.capability == this._manageCapability))) {
+
       var host = aPermission.host;
       var capabilityString = this._getCapabilityString(aPermission.capability);
       var p = new Permission(host,
@@ -322,6 +345,9 @@ var gPermissionManager = {
           continue;
         }
 
+        if (!hosts)
+          continue;
+
         hostList = hosts.split(",");
         var capability = prefList[i][1];
         for (var j = 0; j < hostList.length; ++j) {
