@@ -1,4 +1,4 @@
-//@line 41 "/export/home/mozilla/uild/firefox1.5.0.2/mozilla/toolkit/components/printing/content/printProgress.js"
+//@line 41 "/export/home/slave/ffslave/mozilla-1.9.1-solaris-sparc-nightly/build/toolkit/components/printing/content/printProgress.js"
 
 // dialog is just an array we'll use to store various properties from the dialog document...
 var dialog;
@@ -59,6 +59,26 @@ var progressListener = {
         var percentPrint = getString( "progressText" );
         percentPrint = replaceInsert( percentPrint, 1, 100 );
         dialog.progressText.setAttribute("value", percentPrint);
+
+        var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"].
+                     getService(Components.interfaces.nsIWindowMediator);
+        if (wm && wm.getMostRecentWindow(null) == window) {
+          // This progress dialog is the currently active window. In
+          // this case we need to make sure that some other window
+          // gets focus before we close this dialog to work around the
+          // buggy Windows XP Fax dialog, which ends up parenting
+          // itself to the currently focused window and is unable to
+          // survive that window going away. What happens without this
+          // opener.focus() call on Windows XP is that the fax dialog
+          // is opened only to go away when this dialog actually
+          // closes (which can happen asynchronously, so the fax
+          // dialog just flashes once and then goes away), so w/o this
+          // fix, it's impossible to fax on Windows XP w/o manually
+          // switching focus to another window (or holding on to the
+          // progress dialog with the mouse long enough).
+          opener.focus();
+        }
+
         window.close();
       }
     },
